@@ -10,7 +10,6 @@ import os
 import sys
 
 from isbnlib import config
-from isbnlib import registry
 
 # env
 PY2 = sys.version < '3'
@@ -29,6 +28,8 @@ DEBUG=False
 [SYS]
 URLOPEN_TIMEOUT=10
 THREADS_TIMEOUT=12
+LOAD_METADATA_PLUGINS=True
+LOAD_FORMATTER_PLUGINS=True
 [SERVICES]
 DEFAULT_SERVICE=goob
 VIAS_MERGE=parallel
@@ -90,6 +91,21 @@ if conf.has_section('SYS'):
     # get user defined values for timeouts
     URLOPEN_TIMEOUT = float(conf.get('SYS', 'URLOPEN_TIMEOUT'))
     THREADS_TIMEOUT = float(conf.get('SYS', 'THREADS_TIMEOUT'))
+    # URLOPEN_TIMEOUT is used by webservice.py and is a number
+    config.seturlopentimeout(URLOPEN_TIMEOUT)
+    # THREADS_TIMEOUT is used by vias.py and is a number
+    config.setthreadstimeout(THREADS_TIMEOUT)
+    # LOAD_METADATA_PLUGINS
+    LOAD_METADATA_PLUGINS = bool(
+        conf.get('SYS', 'LOAD_METADATA_PLUGINS') == 'True')
+    config.set_option('LOAD_METADATA_PLUGINS', LOAD_METADATA_PLUGINS)
+    # LOAD_FORMATTER_PLUGINS
+    LOAD_FORMATTER_PLUGINS = bool(
+        conf.get('SYS', 'LOAD_FORMATTER_PLUGINS') == 'True')
+    config.set_option('LOAD_FORMATTER_PLUGINS', LOAD_FORMATTER_PLUGINS)
+
+# only now we can import registry!
+from isbnlib import registry
 
 if conf.has_section('SERVICES'):
     for o, v in conf.items('SERVICES'):
@@ -110,12 +126,6 @@ if conf.has_section('MODULES'):  # pragma: no cover
     for o, v in conf.items('MODULES'):
         config.set_option(o.upper(), v)
 
-# URLOPEN_TIMEOUT is used by webservice.py
-config.seturlopentimeout(URLOPEN_TIMEOUT)
-
-# THREADS_TIMEOUT is used by vias.py
-config.setthreadstimeout(THREADS_TIMEOUT)
-
 # set CONF_PATH
 if not CONF_PATH:
     if VIRTUAL:
@@ -130,7 +140,7 @@ if not CONF_PATH:
         pass
 
 # set metadata cache
-if config.options.get('CACHE', 'UNDEFINED').lower() == 'no':
+if config.options.get('CACHE', 'UNDEFINED').lower() == 'none':
     registry.set_cache(None)
 else:
     CACHE_FILE = '.metacache'
