@@ -3,9 +3,8 @@
 
 import sys
 
-from ..app import config, doi2tex, quiet_errors
+from ..app import doi2tex, quiet_errors
 
-TO = 30
 PREFIX = 'isbn_'
 
 
@@ -16,7 +15,6 @@ def usage(prefix=PREFIX):
 
 def main(doi=None, prefix=PREFIX):
     sys.excepthook = quiet_errors
-    config.setsocketstimeout(TO)
     try:
         doi = sys.argv[1] if not doi else doi[1]
         data = doi2tex(doi)
