@@ -10,7 +10,7 @@ from ..app import goom, quiet_errors, uprint
 PREFIX = 'isbn_'
 
 
-def usage(ofmts="labels", prefix=PREFIX):
+def usage(ofmts='labels', prefix=PREFIX):
     sys.stderr.write('Usage: %sgoom "words" [%s] \n' % (prefix, ofmts))
     return 1
 
@@ -33,6 +33,7 @@ def main(args=None, prefix=PREFIX):
         for r in goom(words):
             uprint((fmtbib(fmt, r)))
             print('')
+        return 0
     except:
         bibf = fmts[:]
         try:
